@@ -84,7 +84,7 @@
 #define KEMOTICONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KEMOTICONS_NO_DEPRECATED
-#  define KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
+#  define KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KEMOTICONS_NO_DEPRECATED_WARNINGS
 #  define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0x56a00
+#    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
